SIMILE | Timeline | Documentation

- SIMILE
- Timeline
- Documentation

# Timeline Documentation

## Getting Started

- The basics, briefly how timelines work
- How to create timelines, a step-by-step tutorial

## API

- Timelines
- Bands
- Ethers
- Ether painters
- Decorators, for now, read the code
- Event sources, for now, read the code
- Event painters
- Layouts, for now, read the code
- Themes, for now, read the code
- Labellers, for now, read the code

Utilities

- Data structure utilities, for now, read the code
- Date/time utilities, for now, read the code
- Debug utilities, for now, read the code
- DOM utilities, for now, read the code
- Graphics utilities, for now, read the code
- Platform utilities, for now, read the code
- XmlHttp utilities, for now, read the code